macro_rules! get_test_bin {
($x:expr) => { ... };
}Expand description
Returns the crate’s binary as a Command that can be used for integration
tests.
Arguments
bin_name- The name of the binary you want to test. It must be a string literal.
Remarks
It will fail to compile if the bin_name is incorrect. The bin_name is
used for creating an environment variable.
If you want to not use a string literal every time then you can define a macro that returns a string literal:
macro_rules! my_cli_app {
() => ( "my_cli_app" )
}And then use my_cli_app!() as the argument.